@@ -17,6 +17,7 @@ from a2p2.instrument import Instrument
 
 logger = logging.getLogger(__name__)
 
+
 class VltiInstrument(Instrument):
 
     def __init__(self, facility, insname):
@@ -34,26 +35,24 @@ class VltiInstrument(Instrument):
         else:
             return defaultvalue
 
-
     def getSequence(self, ob):
-    # We may look at ob.observationSchedule but at present tuime schedule still is computed on a2p2 side
-        sci=[]
-        cal=[]
+        # We may look at ob.observationSchedule but at present tuime schedule still is computed on a2p2 side
+        sci = []
+        cal = []
         for observationConfiguration in ob.observationConfiguration:
             if 'SCIENCE' in observationConfiguration.type:
                 sci.append(observationConfiguration)
             else:
                 cal.append(observationConfiguration)
-        if len(sci)+len(cal) <= 2: # return [CAL] [SCI]
+        if len(sci)+len(cal) <= 2:  # return [CAL] [SCI]
             return cal+sci
         # else return CAL1 SCI CAL2 [SCI CAL3] [SCI CAL4]
-        seq=[]
-        for c in cal :
+        seq = []
+        for c in cal:
             seq.append(c)
-            seq+=sci
+            seq += sci
         return seq[0:-1]
 
-
     # checkOB() must be defined by each instruments
     # def checkOB(self, ob, p2container=None):
     # consider dryMode if p2container is None else check again and submit on p2 side
@@ -83,7 +82,8 @@ class VltiInstrument(Instrument):
                     p2container.containerId, folderName)
                 ui.addToLog(f"concatenation '{folderName}' created")
             else:
-                folder, _ = api.createFolder(p2container.containerId, folderName)
+                folder, _ = api.createFolder(
+                    p2container.containerId, folderName)
                 ui.addToLog(f"folder '{folderName}' created")
 
             # update parent tree since we created a new subfolder
@@ -97,11 +97,11 @@ class VltiInstrument(Instrument):
         ui.addToLog("OB checked / preparing  submission...")
         self.checkOB(ob, p2container)
 
-        ## refresh and select last created element tree
+        # refresh and select last created element tree
         self.ui.updateTree(p2container.run, p2container.containerId)
         self.ui.selectTreeItem(p2container.containerId)
 
-    def getCoords(self, target, requirePrecision=True ):
+    def getCoords(self, target, requirePrecision=True):
         """
         Format coordinates from given target to be VLTI compliant.
         Throws an exception if requirePrecision is true and given inputs have less than 3 (RA) or 2 (DEC) digits.
@@ -168,14 +168,15 @@ class VltiInstrument(Instrument):
 
     def checkIssVltiType(self, acqTSF):
         # TODO improve handling of this keyword using input from Aspro2's OB
-        psection="p2.iss.vltitype"
+        psection = "p2.iss.vltitype"
         if self.facility.a2p2client.preferences.getConfigKeys(psection):
-            vltitypePref=[v for v in self.facility.a2p2client.preferences.getConfigKeys(psection) if self.isInRange(acqTSF.tpl, "ISS.VLTITYPE", v) ]
+            vltitypePref = [v for v in self.facility.a2p2client.preferences.getConfigKeys(
+                psection) if self.isInRange(acqTSF.tpl, "ISS.VLTITYPE", v)]
             if vltitypePref:
-                self.ui.addToLog(f"Using {psection} preference value : '{vltitypePref}'")
+                self.ui.addToLog(
+                    f"Using {psection} preference value : '{vltitypePref}'")
                 acqTSF.ISS_VLTITYPE = vltitypePref
 
-
     def getA2p2Comments(self):
         return 'Generated by ' + self.facility.a2p2client.preferences.getP2UserCommentName() + \
                ' using ASPRO 2 (c) JMMC on ' + \
@@ -199,7 +200,7 @@ class VltiInstrument(Instrument):
         self.ditTable = json.load(open(f))
         return self.ditTable
 
-    def getDit(self, tel, spec, pol, K, dualFeed=False, showWarning=False):
+    def getDit(self, tel, spec, pol, K, dualFeed=False, targetName="", showWarning=False):
         """
         finds DIT according to ditTable and K magnitude K
 
@@ -215,6 +216,7 @@ class VltiInstrument(Instrument):
         # if spec == "LOW":
         #    spec="HIGH"
         ditTable = self.getDitTable()
+        version = ditTable["VERSION"]
         mags = ditTable["AT"][spec][pol]['MAG']
         dits = ditTable["AT"][spec][pol]['DIT']
         if dualFeed:
@@ -224,7 +226,7 @@ class VltiInstrument(Instrument):
         if tel == "UT":
             dK += ditTable["AT"]['Kut']
         for i, d in enumerate(dits):
-            if mags[i] < (K - dK) and (K - dK) <= mags[i + 1]:
+            if mags[i] <= (K - dK) and (K - dK) <= mags[i + 1]:
                 return d
 
         # handle out of bounds
@@ -233,11 +235,19 @@ class VltiInstrument(Instrument):
         for i, d in enumerate(dits):
             kmin = min(kmin, mags[i] + dK)
             kmax = max(kmax, mags[i + 1] + dK)
-        if kmin == K:
-            return minDIT
-        raise ValueError(
-            "K mag (%f) is out of ranges [%f,%f]\n for this mode (tel=%s, spec=%s, pol=%s, dualFeed=%s)" % (
-                K, kmin, kmax, tel, spec, pol, dualFeed))
+
+        if showWarning:
+            self.ui.ShowWarningMessage(
+                f"According to the template manual {version} :\n   K mag ({K})  is out of ranges [{kmin},{kmax}]\n for this mode ( ∆K={dK} tel={tel}, spec={spec}, pol={pol}, dualFeed={dualFeed}) \n  for target '{targetName}'")
+
+        # always return a value to avoid unsupported operations
+        if K < kmin:
+            return min(dits)
+        return max(dits)
+
+#        raise ValueError(
+#            "K mag (%f) of '%s' is out of ranges [%f,%f]\n for this mode (tel=%s, spec=%s, pol=%s, dualFeed=%s)" % (
+#                K, targetName, kmin, kmax, tel, spec, pol, dualFeed))
 
     def getRangeTable(self):
         if self.rangeTable:
@@ -272,6 +282,7 @@ class VltiInstrument(Instrument):
             return value >= rangeTable[_tpl][key]['min'] and \
                 value <= rangeTable[_tpl][key]['max']
         if 'list' in rangeTable[_tpl][key].keys():
+            print(f"Searching {value} in {rangeTable[_tpl][key]['list']}")
             #
             # hack set to check for coordinates convention define by p2
             # vlue will be checked by p2 later...
@@ -340,7 +351,7 @@ class VltiInstrument(Instrument):
         if not key in rangeTable[_tpl].keys():
             raise ValueError(
                 "unknown keyword '%s' in template '%s'" % (key, tpl))
-        if 'default' in rangeTable[_tpl][key].keys() :
+        if 'default' in rangeTable[_tpl][key].keys():
             return rangeTable[_tpl][key]['default']
         return None
 
@@ -364,7 +375,6 @@ class VltiInstrument(Instrument):
                 res[key] = rangeTable[_tpl][key]["default"]
         return res
 
-
     def getSkyDiff(self, ra, dec, ftra, ftdec):
         science = SkyCoord(ra, dec, frame='icrs', unit='deg')
         ft = SkyCoord(ftra, ftdec, frame='icrs', unit='deg')
@@ -431,7 +441,7 @@ class VltiInstrument(Instrument):
             msg = 'OB ' + str(obId) + ' submitted successfully on P2\n' + ob[
                 'name'] + ' has WARNING.\n see LOG for details.'
         self.ui.addToLog('\n')
-        #self.ui.ShowInfoMessage(msg)
+        # self.ui.ShowInfoMessage(msg)
         self.ui.addToLog(msg)
         self.ui.addToLog('\n'.join(response['messages']) + '\n\n')
 
@@ -559,4 +569,4 @@ class OBConstraints(TSF):
     def __init__(self, instrument):
         TSF.__init__(self, instrument, "instrumentConstraints.tsf")
         # WORKARROUND missing param in p2 json but valid and used in our code
-        instrument.getRangeTable()[self.tpl]["name"]={}
+        instrument.getRangeTable()[self.tpl]["name"] = {}
